@@ -23,7 +23,7 @@ int TableMain()
 	int *pos = NULL;
     int retval = 0;
 
-	/* ݒ */
+	/*  */
 	a1 = 66, a2 = 34;  /* case */
 	b1 = 90, b2 = 10;  /* control */
 	Sobs = 11;
@@ -61,9 +61,9 @@ int TableMain()
 		//				showMatrix(result);
 	}			
 
-    /* loge[uNA */
+    /* logơ֥륯ꥢ */
     FactorialDeleteFactorial();
-    /* \tablẽJ */
+    /* ¤tableΥ곫 */
     TableFinalTable(&Tbl);
 
 #ifdef DBG
@@ -76,9 +76,9 @@ int TableMain()
 
 
 /************************************************************************/
-/*	e[u														*/
-/*	tbl		O		e[u											*/
-/*	Ԃl	O		e[u											*/
+/*	ơ֥														*/
+/*	tbl		O		ơ֥											*/
+/*	֤	O		ơ֥											*/
 /************************************************************************/
 int TableInitTable(SnpTable *tbl)
 {
@@ -92,28 +92,28 @@ int TableInitTable(SnpTable *tbl)
 
 
 /************************************************************************/
-/*	e[u쐬ij												*/
-/*	tbl			I	e[u											*/
-/*	numHori		I	̃f[^									*/
-/*	numVert		I	̃f[^									*/
-/*	Ԃl		NORMAL_STATUS:		I							*/
-/*				ERROR_MEMORY_ALLOC:	̊mۂɎs				*/
+/*	ơ֥ʽ												*/
+/*	tbl			I	ơ֥											*/
+/*	numHori		I	ʿΥǡ									*/
+/*	numVert		I	ľΥǡ									*/
+/*	֤		NORMAL_STATUS:		ｪλ							*/
+/*				ERROR_MEMORY_ALLOC:	γݤ˼Ԥ				*/
 /************************************************************************/
 int TableCreateTable(SnpTable *tbl, int numHori, int numVert)
 {
 	int *pos = NULL;
 	int retVal = 0;
 
-	TableInitTable(tbl);	/* Tablȅ */
+	TableInitTable(tbl);	/* Tableν */
 
-    /* e[ũm */
+    /* ơ֥Υ */
     tbl->table = (int**)mallocInt2Dim(numHori, numVert);
 	if (NULL == tbl->table) {
 		retVal = ERROR_MEMORY_ALLOC;
 		goto finalize;
 	}
 
-	/* yѐ̘a̔z */
+	/* ʿڤӿľ¤ */
 	tbl->horizontalSum = (int*)malloc1Dim(sizeof(int), numHori);
 	if (NULL == tbl->horizontalSum) {
 		retVal = ERROR_MEMORY_ALLOC;
@@ -128,21 +128,21 @@ int TableCreateTable(SnpTable *tbl, int numHori, int numVert)
 finalize:;
 	switch (retVal) {
 	case NORMAL_STATUS:
-		return retVal;	/* ɂ͂ŏI */
+		return retVal;	/* ˤϤǽ򽪤 */
 	case ERROR_MEMORY_ALLOC:
 		printf("ERROR [TableCreateTable]: Cannot create Table.\n");
 		break;
 	}
 
-	TableFinalTable(tbl);	/*@G[̃̈@*/
+	TableFinalTable(tbl);	/*顼Υΰ*/
 
 	return retVal;
 }
 
 
 /************************************************************************/
-/*	e[uI													*/
-/*	tbl		I	e[u												*/
+/*	ơ֥뽪λ													*/
+/*	tbl		I	ơ֥												*/
 /************************************************************************/
 int TableFinalTable(SnpTable *tbl)
 {
@@ -166,19 +166,19 @@ int TableFinalTable(SnpTable *tbl)
 
 
 /************************************************************************/
-/*	S̐li^j̃e[u쐬								*/
-/*	tbl		I	e[u												*/
-/*	a1		I	a1iGenotype1, Casej									*/
-/*	a2		I	a2iGenotype2, Casej									*/
-/*	b1		I	b1iGenotype1, Controlj								*/
-/*	b2		I	b2iGenotype2, Controlj								*/
-/*	Ԃl	0:	폈												*/
+/*	Ĥο͡ˤΥơ֥								*/
+/*	tbl		I	ơ֥												*/
+/*	a1		I	a1Genotype1, Case									*/
+/*	a2		I	a2Genotype2, Case									*/
+/*	b1		I	b1Genotype1, Control								*/
+/*	b2		I	b2Genotype2, Control								*/
+/*	֤	0:													*/
 /************************************************************************/
 int TableMakeTable4Int(SnpTable *tbl, int a1, int a2, int b1, int b2)
 {
 	int n;
 
-    /* e[ȕ */
+    /* ơ֥ν */
     TableInitTable(tbl);
     TableCreateTable(tbl, ROW, COLUMN);
 
@@ -201,9 +201,9 @@ int TableMakeTable4Int(SnpTable *tbl, int a1, int a2, int b1, int b2)
 
 
 /************************************************************************/
-/*	2*2̔zi^j̃e[u쐬								*/
-/*	tbl		O	e[u												*/
-/*	T		I	e[u̒l											*/
+/*	2*2ˤΥơ֥								*/
+/*	tbl		O	ơ֥												*/
+/*	T		I	ơ֥											*/
 /************************************************************************/
 int TableMakeTableIntArray(SnpTable *tbl, int **T)
 {
@@ -211,7 +211,7 @@ int TableMakeTableIntArray(SnpTable *tbl, int **T)
 	int a1 = 0, a2 = 0, b1 = 0, b2 = 0;
 	int n1 = 0, n2 = 0;
 
-    /* e[ȕ */
+    /* ơ֥ν */
     TableInitTable(tbl);
     TableCreateTable(tbl, ROW, COLUMN);
 
@@ -239,15 +239,15 @@ int **TableGetTable(SnpTable T)
 
 
 /************************************************************************/
-/*	V															*/
-/*	tbl		I	e[u												*/
+/*																*/
+/*	tbl		I	ơ֥												*/
 /*	a1		I															*/
 /*	result	O														*/
 /*																		*/
 /************************************************************************/
 int TableNewCandidate(SnpTable tbl, int a1, int **result)
 {
-	/*@f[^TCỸ`FbN@*/
+	/*ǡΥå*/
 	if (a1 < 0) {
 		printf("negative value\n"); /* out of bounds */
 		return 1;
@@ -283,9 +283,9 @@ int TableNewTable(SnpTable tbl, int a1, int **result)
 
 
 /************************************************************************/
-/*	LľvZ															*/
-/*	tbl		I	e[u												*/
-/*	Ԃl		Ll														*/
+/*	Lͤη׻															*/
+/*	tbl		I	ơ֥												*/
+/*	֤		L														*/
 /************************************************************************/
 int TableCalcL(SnpTable tbl)	/* lower limit */
 {	int result = 0;
@@ -300,9 +300,9 @@ int TableCalcL(SnpTable tbl)	/* lower limit */
 
 
 /************************************************************************/
-/*	UľvZ															*/
-/*	tbl		I	e[u												*/
-/*	Ԃl		Ul														*/
+/*	Uͤη׻															*/
+/*	tbl		I	ơ֥												*/
+/*	֤		U														*/
 /************************************************************************/
 int TableCalcU(SnpTable tbl)	/* upper limit */
 {
@@ -318,9 +318,9 @@ int TableCalcU(SnpTable tbl)	/* upper limit */
 
 
 /************************************************************************/
-/*	PearsoñXRǍvZ												*/
-/*	T		I		e[ui2x2j										*/
-/*	Ԃl			XRA												*/
+/*	PearsonΥη׻												*/
+/*	T		I		ơ֥2x2										*/
+/*	֤															*/
 /************************************************************************/
 double TableCalcPearsonScore(int **T)		/* 12) Pearsonscore */
 {
@@ -334,7 +334,7 @@ double TableCalcPearsonScore(int **T)		/* 12) Pearsonscore */
 	b1 = T[1][0];		b2 = T[1][1];		b = b1 + b2;/* control */
 	n1 = a1 + b1;		n2 = a2 + b2;		n = n1 + n2;
 
-    /* 0̂߁Aꂪ0Ȃ-1Ԃ */
+    /* 0Τᡢʬ줬0ʤ-1֤ */
     denominator = (double)a * b * n1 * n2;
     if (denominator == 0){
         return -1;
@@ -347,10 +347,10 @@ double TableCalcPearsonScore(int **T)		/* 12) Pearsonscore */
 }
 
 /************************************************************************/
-/*	v̌vZ																*/
-/*	tbl		I	e[u												*/
-/*	Sobs	I	e[u												*/
-/*	Ԃl		v̒l													*/
+/*	vη׻																*/
+/*	tbl		I	ơ֥												*/
+/*	Sobs	I	ơ֥												*/
+/*	֤		v													*/
 /************************************************************************/
 int TableCalcV(SnpTable tbl, double Sobs) /* lower boundary of X where S>Sobs */
 {
@@ -373,9 +373,9 @@ int TableCalcV(SnpTable tbl, double Sobs) /* lower boundary of X where S>Sobs */
 
 
 /************************************************************************/
-/*	tbl		I	e[u												*/
-/*	Sobs	I	e[u												*/
-/*	Ԃl		Wl														*/
+/*	tbl		I	ơ֥												*/
+/*	Sobs	I	ơ֥												*/
+/*	֤		W														*/
 /************************************************************************/
 int TableCalcW(SnpTable tbl, double Sobs) /* upper boundary of X where S>Sobs */
 {
@@ -399,10 +399,10 @@ int TableCalcW(SnpTable tbl, double Sobs) /* upper boundary of X where S>Sobs */
 
 
 /************************************************************************/
-/*	ʒl̃[ǧvZ												*/
-/*	tbl		I	e[u												*/
+/*	ȽͤΥ롼Ȥη׻												*/
+/*	tbl		I	ơ֥												*/
 /*	Sobs	I															*/
-/*	Ԃl	ʒl̃[g												*/
+/*	֤	ȽͤΥ롼												*/
 /************************************************************************/
 double TableRootD(SnpTable tbl, double Sobs)
 {
@@ -411,12 +411,12 @@ double TableRootD(SnpTable tbl, double Sobs)
 
 
 /************************************************************************/
-/*	ʒľvZ														*/
-/*	tbl		I	e[u												*/
+/*	Ƚͤη׻														*/
+/*	tbl		I	ơ֥												*/
 /*	Sobs	I															*/
-/*	Ԃl	ʒl														*/
+/*	֤	Ƚ														*/
 /************************************************************************/
-double TableDiscriminant(SnpTable tbl, double Sobs) /* ʎ */
+double TableDiscriminant(SnpTable tbl, double Sobs) /* Ƚ̼ */
 {
 	int a = 0, b = 0;
 	int n1 = 0, n2 = 0, n = 0;
@@ -434,8 +434,8 @@ double TableDiscriminant(SnpTable tbl, double Sobs) /* ʎ */
 
 
 /************************************************************************/
-/*	ʒľvZ														*/
-/*	tbl			I	e[u											*/
+/*	Ƚͤη׻														*/
+/*	tbl			I	ơ֥											*/
 /************************************************************************/
 int TableTwoParts(SnpTable tbl, double Sobs)
 {
@@ -451,9 +451,9 @@ int TableTwoParts(SnpTable tbl, double Sobs)
 
 
 /************************************************************************/
-/*	FstľvZ															*/
-/*	T		I	e[u												*/
-/*	Ԃl	Fstl														*/
+/*	Fstͤη׻															*/
+/*	T		I	ơ֥												*/
+/*	֤	Fst														*/
 /************************************************************************/
 double TableCalcFst(int **T)		/* 12) Pearsonscore */
 {
@@ -483,11 +483,11 @@ double TableCalcFst(int **T)		/* 12) Pearsonscore */
 
 
 /************************************************************************/
-/*	f[^s̕\													*/
-/*	data	I	\s											*/
+/*	ǡɽ													*/
+/*	data	I	ɽ											*/
 /*	len1	I															*/
 /*	len2	I															*/
-/*	Ԃl	Ȃ														*/
+/*	֤	ʤ														*/
 /************************************************************************/
 void TableShowMatrix(int **data, int len1, int len2)
 {
@@ -502,10 +502,10 @@ void TableShowMatrix(int **data, int len1, int len2)
 
 
 /************************************************************************/
-/*	f[^̕\														*/
-/*	data	I	\z											*/
+/*	ǡɽ														*/
+/*	data	I	ɽ											*/
 /*	len		I															*/
-/*	Ԃl	Ȃ														*/
+/*	֤	ʤ														*/
 /************************************************************************/
 void TableShowVector(int *data, int len)
 {
@@ -519,8 +519,8 @@ void TableShowVector(int *data, int len)
 
 
 /************************************************************************/
-/*	mu̒ľvZ														*/
-/*	T	I	e[u													*/
+/*	muͤη׻														*/
+/*	T	I	ơ֥													*/
 /*																		*/
 /*																		*/
 /*																		*/
@@ -530,7 +530,7 @@ double TableCalcMu(int **T)
 	int a1 = 0, a2 = 0, a = 0;
 	int b1 = 0, b2 = 0, b = 0;
 	int n1 = 0, n2 = 0, n = 0;
-	double logComb1 = 0.0, logComb2 = 0.0;	/* gݍ킹Log */
+	double logComb1 = 0.0, logComb2 = 0.0;	/* Ȥ߹碌Log */
 
 	a1 = T[0][0];		a2 = T[0][1];		a = a1 + a2;	/* case */
 	b1 = T[1][0];		b2 = T[1][1];		b = b1 + b2;	/* control */
@@ -625,9 +625,9 @@ int TableJudgeCj(double Sobs, int **T, int len1, int len2)
 /************************************************************************/
 double TableCalcR(int **T1, int len1, int len2, int **T2)
 {
-	/* IɈxvZΏ\ƂASYɕύX */
-	double logNum = 0.0; /* q */
-	double logDen = 0.0; /*  */
+	/* Ū˰ٷ׻нʬȤ르ꥺѹ */
+	double logNum = 0.0; /* ʬ */
+	double logDen = 0.0; /* ʬ */
 	int i = 0, j = 0;
 	double logResult = 0.0;
 	double retVal = 0.0;
@@ -644,20 +644,20 @@ double TableCalcR(int **T1, int len1, int len2, int **T2)
 	return retVal;
 }
 
-/* 􌻕\̃XRAvZ */
+/* ɽΥ׻ */
 double TableCalcScore(int **T)
 {
     double score = 0;
                 
-    /* XRAvZ */
+    /* ׻ */
     switch(iWay){
-        case 0: /* PeasonScorevZ */
+        case 0: /* PeasonScore׻ */
                 score = TableCalcPearsonScore(T);
                 break;
-        case 1: /* FstvZ */
+        case 1: /* Fst׻ */
                 score = TableCalcFst(T);
                 break;
-        default:/* `ĂȂl̏ꍇ */
+        default:/* Ƥʤͤξ */
                 score = -1;
                 break;
     }
@@ -665,13 +665,13 @@ double TableCalcScore(int **T)
     return score; 
 }
 
-/* mulogľvZ */
+/* mulogͤη׻ */
 double TableCalcLogMu(int **T)
 {
 	int a1 = 0, a2 = 0, a = 0;
 	int b1 = 0, b2 = 0, b = 0;
 	int n1 = 0, n2 = 0, n = 0;
-	double logComb1 = 0.0, logComb2 = 0.0;	/* gݍ킹Log */
+	double logComb1 = 0.0, logComb2 = 0.0;	/* Ȥ߹碌Log */
 
 	a1 = T[0][0];		a2 = T[0][1];		a = a1 + a2;	/* case */
 	b1 = T[1][0];		b2 = T[1][1];		b = b1 + b2;	/* control */
@@ -720,7 +720,7 @@ void TableMarkov1(SnpTable T, double Score, int **table)
     if ( (newA1 < l) || (newA1 > u) ){
         return; //unchanged
     }
-    /* newX̃m */
+    /* newXΥ */
     newX = (int**)mallocInt2Dim(ROW, COLUMN);
     if (NULL == newX) { goto finalize; }
 
@@ -746,7 +746,7 @@ void TableMarkov1(SnpTable T, double Score, int **table)
     }
 
 finalize:;
-    /* mۂJ */
+    /* ݤ */
     freeInt2Dim(newX, ROW);
 }
 
@@ -794,7 +794,7 @@ void TableMarkov2(SnpTable T, double Score, int **table)
     }
 
     /* new candidate */
-    /* newX̃m */
+    /* newXΥ */
     newX = (int**)mallocInt2Dim(ROW, COLUMN);
     if (NULL == newX) { goto finalize; }
 
@@ -823,10 +823,10 @@ void TableMarkov2(SnpTable T, double Score, int **table)
         oldA1 = T.table[0][0];
         newA1 = oldA1;
 
-        /* oldA1X̃m */
+        /* oldA1XΥ */
         oldA1X = (int**)mallocInt2Dim(ROW, COLUMN);
         if (NULL == oldA1X) { goto finalize; }
-        /* newA1X̃m */
+        /* newA1XΥ */
         newA1X = (int**)mallocInt2Dim(ROW, COLUMN);
         if (NULL == newA1X) { goto finalize; }
 
@@ -856,7 +856,7 @@ void TableMarkov2(SnpTable T, double Score, int **table)
     }
 
 finalize:;
-    /* mۂJ */
+    /* ݤ */
     freeInt2Dim(newX, ROW);
     freeInt2Dim(oldA1X, ROW);
     freeInt2Dim(newA1X, ROW);
